// Ionic Starter App

// angular.module is a global place for creating, registering and retrieving Angular modules
// 'starter' is the name of this angular module example (also set in a <body> attribute in index.html)
// the 2nd parameter is an array of 'requires'
// 'starter.controllers' is found in controllers.js
angular.module('starter', ['ionic', 'starter.services', 'starter.controllers'],function($httpProvider){
	
	// Use x-www-form-urlencoded Content-Type
	$httpProvider.defaults.headers.post['Content-Type'] = 'application/x-www-form-urlencoded;charset=utf-8';

	/**
	 * The workhorse; converts an object to x-www-form-urlencoded serialization.
	 * @param {Object} obj
	 * @return {String}
	 */
	var param = function (obj) {
		var query = '', name, value, fullSubName, subName, subValue, innerObj, i;

		for (name in obj) {
			value = obj[name];

			if (value instanceof Array) {
				for (i = 0; i < value.length; ++i) {
					subValue = value[i];
					fullSubName = name + '[' + i + ']';
					innerObj = {};
					innerObj[fullSubName] = subValue;
					query += param(innerObj) + '&';
				}
			}
			else if (value instanceof Object) {
				for (subName in value) {
					subValue = value[subName];
					fullSubName = name + '[' + subName + ']';
					innerObj = {};
					innerObj[fullSubName] = subValue;
					query += param(innerObj) + '&';
				}
			}
			else if (value !== undefined && value !== null)
				query += encodeURIComponent(name) + '=' + encodeURIComponent(value) + '&';
		}

		return query.length ? query.substr(0, query.length - 1) : query;
	};

	// Override $http service's default transformRequest
	$httpProvider.defaults.transformRequest = [function (data) {
			return angular.isObject(data) && String(data) !== '[object File]' ? param(data) : data;
		}];
})

.run(function($ionicPlatform) {
  $ionicPlatform.ready(function() {
    // Hide the accessory bar by default (remove this to show the accessory bar above the keyboard
    // for form inputs)
    if(window.cordova && window.cordova.plugins.Keyboard) {
      cordova.plugins.Keyboard.hideKeyboardAccessoryBar(true);
    }
    if(window.StatusBar) {
      // org.apache.cordova.statusbar required
      StatusBar.styleDefault();
    }
  });
})

.config(function($stateProvider, $urlRouterProvider) {
  $stateProvider

    .state('app', {
      url: "/app",
      abstract: true,
      templateUrl: "templates/menu.html",
      controller: 'AppCtrl'
    })
    .state('app.maglist', {
      url: "/magazine-list/:cat_index",
      views: {
        'menuContent' :{
          templateUrl: "templates/magazine-list.html",
          controller: 'MagazineListCtrl'
        }
      }
    })
    .state('app.magazine', {
      url: "/magazine/:id",
      views: {
        'menuContent' :{
          templateUrl: "templates/magazine.html",
          controller: 'MagazineCtrl'
        }
      },
	  camefrom : {
		  active : false
	  }
    })
    .state('app.magazine-gallery', {
      url: "/magazine-gallery/:id",
      views: {
        'menuContent' :{
          templateUrl: "templates/gallery.html",
          controller: 'MagazineGalleryCtrl'
        }
      }
    })
	.state('app.magazine-datasheet', {
      url: "/magazine-datasheet/:id",
      views: {
        'menuContent' :{
          templateUrl: "templates/datasheet.html",
          controller: 'MagazineDatasheetCtrl'
        }
      }
    })
	.state('app.magazine-proagainst', {
      url: "/magazine-proagainst/:id",
      views: {
        'menuContent' :{
          templateUrl: "templates/proagainst.html",
          controller: 'MagazineProagainstCtrl'
        }
      }
    })
	.state('app.magazine-howitworks', {
      url: "/magazine-howitworks/:id",
      views: {
        'menuContent' :{
          templateUrl: "templates/howitworks.html",
          controller: 'MagazineHowitworksCtrl'
        }
      }
    })
	.state('app.magazine-comment', {
      url: "/magazine-comment/:id",
      views: {
        'menuContent' :{
          templateUrl: "templates/comment.html",
          controller: 'MagazineCommentCtrl'
        }
      }
    })
	.state('app.search', {
      url: "/search",
	  views: {
        'menuContent' :{
          templateUrl: "templates/search.html",
          controller: 'SearchCtrl'
        }
	  },
	  data : {
		  active : true
	  }
	});
  // if none of the above states are matched, use this as the fallback
  $urlRouterProvider.otherwise('/app/magazine-list/0');
});

var controllers = angular.module('starter.controllers', []);
var services = angular.module('starter.services', []);